Technical Reference
===================

This section contains comprehensive descriptions of CSET, and its various
components.

.. toctree::
    :maxdepth: 1

    glossary
    cli
    recipe-format
    operators
    internal
